@@ -10,7 +10,7 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.040000";
+$VERSION = "5.040002";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.40.0) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.40.2) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.40.0
-    or die sprintf "%s: Perl lib version (5.40.0) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.40.2
+    or die sprintf "%s: Perl lib version (5.40.2) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -98,7 +98,7 @@ tie %Config, 'Config', {
     ldlibpthname => 'LD_LIBRARY_PATH',
     libpth => '/lib /usr/lib /usr/pkg/lib',
     osname => 'netbsd',
-    osvers => '10.99.12',
+    osvers => '10.0',
     path_sep => ':',
     privlibexp => '/usr/pkg/lib/perl5/5.40.0',
     scriptdir => '/usr/pkg/lib/perl5/bin',
@@ -107,5 +107,5 @@ tie %Config, 'Config', {
     so => 'so',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.40.0',
+    version => '5.40.2',
 };
